pub struct CandidateIdentifier {
pub id: StringValue<CandidateId>,
pub display_order: Option<StringValue<NonZeroU64>>,
pub short_code: Option<StringValue<NameShortCode>>,
pub expected_confirmation_reference: Option<Box<str>>,
}Expand description
Candidate identifier, but not for 510 document types.
Fields
id: StringValue<CandidateId>The candidate id.
display_order: Option<StringValue<NonZeroU64>>The display order of the candidate.
short_code: Option<StringValue<NameShortCode>>The short code of the candidate.
Note: This can be specified either as an attribute or as a child element, but the attribute takes precedence if both are present. Additionally we only ever output it as an attribute for simplicity.
expected_confirmation_reference: Option<Box<str>>The expected confirmation reference of the candidate.
Implementations
Sourceimpl CandidateIdentifier
impl CandidateIdentifier
Sourcepub fn new(id: CandidateId) -> Self
pub fn new(id: CandidateId) -> Self
Create a new CandidateIdentifier.
Sourcepub fn with_display_order(self, display_order: NonZeroU64) -> Self
pub fn with_display_order(self, display_order: NonZeroU64) -> Self
Set the display order of the candidate.
Sourcepub fn with_short_code(self, short_code: NameShortCode) -> Self
pub fn with_short_code(self, short_code: NameShortCode) -> Self
Set the short code of the candidate.
Sourcepub fn with_expected_confirmation_reference(
self,
reference: impl Into<Box<str>>,
) -> Self
pub fn with_expected_confirmation_reference( self, reference: impl Into<Box<str>>, ) -> Self
Set the expected confirmation reference of the candidate.