pub enum ElectionSubcategory {
Show 16 variants
PS1,
PS2,
AB1,
AB2,
GR1,
GR2,
BC,
GC,
ER1,
TK,
EK,
EP,
NR,
PR,
LR,
IR,
}Expand description
Subcategory of the election, providing more specific information about the type of election.
Variants
PS1
Provinciale Staten (one electoral district)
PS2
Provinciale Staten (multiple electoral districts)
AB1
Waterschapsverkiezingen (less than 19 seats)
AB2
Waterschapsverkiezingen (19 or more seats)
GR1
Gemeenteraad (less than 19 seats)
GR2
Gemeenteraad (19 or more seats)
BC
Bestuurscommissie (Amsterdam, unused)
GC
Gebiedscommissie (Rotterdam, unused)
ER1
Eilandsraad (less than 19 seats, all eilandraden have this)
TK
Tweede kamer
EK
Eerste kamer
EP
Europees Parlement
NR
Todo: Unknown meaning
PR
Todo: Unknown meaning
LR
Todo: Unknown meaning
IR
Todo: Unknown meaning
Implementations
Sourceimpl ElectionSubcategory
impl ElectionSubcategory
Sourcepub fn new(s: impl AsRef<str>) -> Result<Self, EMLError>
pub fn new(s: impl AsRef<str>) -> Result<Self, EMLError>
Create a new ElectionSubcategory from a string, validating its format
Sourcepub fn from_eml_value(
s: impl AsRef<str>,
) -> Result<Self, UnknownElectionSubcategoryError>
pub fn from_eml_value( s: impl AsRef<str>, ) -> Result<Self, UnknownElectionSubcategoryError>
Create a ElectionSubcategory from a &str, if possible.
Sourcepub fn to_eml_value(&self) -> &'static str
pub fn to_eml_value(&self) -> &'static str
Get the &str representation of this ElectionSubcategory.
Sourcepub fn is_subcategory_of(self, category: ElectionCategory) -> bool
pub fn is_subcategory_of(self, category: ElectionCategory) -> bool
Check if this election subcategory is a subcategory of the given election category.